@@ -28,7 +28,7 @@ class PaymentTransactionAdmin(admin.ModelAdmin):
 class PaymentTransactionErrorAdmin(admin.ModelAdmin):
     """Custom admin for the ``PaymentTransactionError`` model."""
     list_display = [
-        'date', 'user', 'user_email', 'response_short', 'transaction_id'
+        'date', 'user', 'user_email', 'response_short', #  FIXME 'transaction_id'
     ]
 
     def user_email(self, obj):
